{% load i18n %}

<div class="detail">
  <dl class="dl-horizontal">
    <dt>{% trans "CancelMode" %}</dt>
    <dd>{{ vnflcmopocc.cancelMode }}</dd>
    <dt>{% trans "ChangedExtConnectivity" %}</dt>
    <dd>{{ vnflcmopocc.changedExtConnectivity }}</dd>
    <dt>{% trans "ChangedInfo" %}</dt>
    <dd>{{ vnflcmopocc.changedInfo }}</dd>
    <dt>{% trans "Error" %}</dt>
    <dd>{{ vnflcmopocc.error }}</dd>
    <dt>{% trans "GrantID" %}</dt>
    <dd>{{ vnflcmopocc.grantId }}</dd>
    <dt>{% trans "ID" %}</dt>
    <dd>{{ vnflcmopocc.id }}</dd>
    <dt>{% trans "IsAutomaticInvocation" %}</dt>
    <dd>{{ vnflcmopocc.isAutomaticInvocation }}</dd>
    <dt>{% trans "IsCancelPending" %}</dt>
    <dd>{{ vnflcmopocc.isCancelPending }}</dd>
    <dt>{% trans "Links" %}</dt>
    <dd>{{ vnflcmopocc.links }}</dd>
    <dt>{% trans "Operation" %}</dt>
    <dd>{{ vnflcmopocc.operation }}</dd>
    <dt>{% trans "OperationParams" %}</dt>
    <dd>{{ vnflcmopocc.operationParams }}</dd>
    <dt>{% trans "OperationState" %}</dt>
    <dd>{{ vnflcmopocc.operationState }}</dd>
    <dt>{% trans "ResourceChanges" %}</dt>
    <dd>{{ vnflcmopocc.resourceChanges  }}</dd>
    <dt>{% trans "StartTime" %}</dt>
    <dd>{{ vnflcmopocc.startTime }}</dd>
    <dt>{% trans "StateEnteredTime" %}</dt>
    <dd>{{ vnflcmopocc.stateEnteredTime }}</dd>
    <dt>{% trans "VnfInstanceID" %}</dt>
    <dd>{{ vnflcmopocc.vnfInstanceId }}</dd>
  </dl>
</div>
