{% load i18n %}

<div class="detail">
  <dl class="dl-horizontal">
    <dt>{% trans "Callback URI" %}</dt>
    <dd>{{ lccnsubscription.callbackUri }}</dd>
    <dt>{% trans "Filter" %}</dt>
    <dd>{{ lccnsubscription.filter }}</dd>
    <dt>{% trans "ID" %}</dt>
    <dd>{{ lccnsubscription.id }}</dd>
    <dt>{% trans "Links" %}</dt>
    <dd>{{ lccnsubscription.links }}</dd>
  </dl>
</div>
