{% load i18n %}

<div class="detail">
  <dl class="dl-horizontal">
    <dt>{% trans "ID" %}</dt>
    <dd>{{ subscription.id }}</dd>
    <dt>{% trans "Links" %}</dt>
    <dd>{{ subscription.links }}</dd>
    <dt>{% trans "Callback Uri" %}</dt>
    <dd>{{ subscription.callback_uri }}</dd>
    <dt>{% trans "Filter" %}</dt>
    <dd>{{ subscription.filter }}</dd>
  </dl>
</div>
