{% extends 'base.html' %}
{% load i18n %}
{% block title %}{% trans "Change External VNF Connectivity" %}{% endblock %}

{% block page_header %}
  {% include "horizon/common/_page_header.html" with title=_("Change External VNF Connectivity") %}
{% endblock page_header %}

{% block main %}
    {% include 'nfv/vnflcm/_change_connectivity.html' %}
{% endblock %}
